Frequency

Enum Frequency 

pub enum Frequency {
    Daily,
    EveryNDays(DayInterval),
    Weekly(Weekday),
    Monthly(DayOfMonth),
    SemiAnnually,
    Annually,
    Biennially,
}
A recurrence frequency for calendar dates.

Variants



Daily

Every calendar day.



EveryNDays(DayInterval)

Every N days, anchored to the schedule’s start date.



Weekly(Weekday)

Every week on the given day.



Monthly(DayOfMonth)

Every month on the given day of the month.

Months that do not contain that day are clamped to the last valid day of the month. For example, the 31st becomes February 28th or 29th.



SemiAnnually

Every six months, anchored to the schedule’s start date.



Annually

Every twelve months, anchored to the schedule’s start date.



Biennially

Every twenty-four months, anchored to the schedule’s start date.